sequencetools.splice_new_elements_between_sequence_elements
===========================================================

.. autofunction:: abjad.tools.sequencetools.splice_new_elements_between_sequence_elements.splice_new_elements_between_sequence_elements
